@@ -19,4 +19,8 @@ class API_NAMES(object):
     CHECK_BALANCE = "v2_checkWalletBalance"
     GET_USER_AUTH_STATUS = "v2_userAuthStatus"
     UNLINK_USER = "v2_unlinkUser"
-    CREATE_QR_SESSION = "v1_qrSession"
\ No newline at end of file
+    CREATE_QR_SESSION = "v1_qrSession"
+    CREATE_CASHBACK_REQUEST = "v2_createCashBackRequest" #GIVE_CASHBACK = 'v2_createRefundPayment'
+    GET_CASHBACK_DETAILS = "v2_getCashbackDetails" #REVERSAL_CASHBACK = 'v2_reversalCashback'
+    CREATE_REVERSE_CASHBACK_REQUEST = "v2_createReverseCashBackRequest"
+    GET_REVERESED_CASHBACK_DETAILS = "v2_getReversedCashBackDetails"
